@@ -1,6 +1,6 @@
 #' @title Nonlinear optimizers using trust regions.
 #'
-#' @description 
+#' @description
 #' Run nonlinear minimizer using trust region algorithm with conjugate
 #' gradient search directions and quasi-Hessian updates.
 #'
@@ -15,11 +15,11 @@
 #'   The user must supply this function.  If an analytic gradient is not
 #'   available, and the method is \code{SR1} or \code{BFGS}, the user should consider a
 #'   numerical approximation using finite differencing (see the
-#'   numDeriv package).  Do not use a finite-differenced gradient with 
+#'   numDeriv package).  Do not use a finite-differenced gradient with
 #'   the \code{Sparse} method.  That will cause a world of hurt.
 #' @param hs An R function that takes x as its first argument.
 #'   Returns a Hessian matrix object of class \code{dgCMatrix} (see the \pkg{Matrix} package).
-#'   This function is called only if the selected method is \code{Sparse}.    
+#'   This function is called only if the selected method is \code{Sparse}.
 #' @param method Valid arguments are \code{SR1},\code{BFGS},and \code{Sparse}.
 #' @param control A list containing control parameters for the optimizer.
 #'   See details.
@@ -29,16 +29,16 @@
 #' @return List containing the following items:
 #'   \item{fval}{Value of the objective function}
 #'   \item{solution}{Parameter vector at the optimum}
-#'   \item{gradient}{Gradient at the optimum} 
+#'   \item{gradient}{Gradient at the optimum}
 #'   \item{hessian}{Estimate of the Hessian at the optimum (as class
 #'     \code{symmetricMatrix}, returned only for \code{Sparse} method).}
 #'   \item{iterations}{Number of iterations before stopping}
 #'   \item{status}{A message describing the last state of the iterator}
 #'   \item{nnz}{For the Sparse method only, the number of nonzero elements in the lower triangle of the Hessian}.
-#' 
+#'
 #' @section Details:
 #'  The following sections explain how to use the package as a whole.
-#' 
+#'
 #' @section Control parameters:
 #' The control list should include the following parameters.
 #' \describe{
@@ -73,12 +73,12 @@
 #'     subproblem is reestimated.  Preconditioners can help the convergence properties of the algorithm.  Default is 1.}
 #' \item{preconditioner}{ID for choice of preconditioner.  0 is the
 #'     identity matrix (default), For the \code{Sparse} method, 1 is a modified Cholesky preconditioner. For the \code{BFGS} method, 1 is the full Cholesky decomposition.  If you select 1 for the \code{SR1} method, the algorithm will use the identity preconditioner instead.}
-#' \item{trust.iter}{Maximum number of conjugate gradient iterations to run when solving the trust region subproblem.  A higher number will lead to more accurate solutions to the subproblem, but may also lead to longer run times. Defaults to 2000.} 
+#' \item{trust.iter}{Maximum number of conjugate gradient iterations to run when solving the trust region subproblem.  A higher number will lead to more accurate solutions to the subproblem, but may also lead to longer run times. Defaults to 2000.}
 #' }
 #'
 #' @section Report levels:
-#' The \code{report.level} control parameter determines how much information is displayed each time the algorithm reports the current state.  Possible values are 
-#' 
+#' The \code{report.level} control parameter determines how much information is displayed each time the algorithm reports the current state.  Possible values are
+#'
 #' \describe{
 #' \item{<=0}{No information (a quiet run)}
 #' \item{1}{Current iteration number, and current value of the objective function.}
@@ -86,9 +86,9 @@
 #' \item{3}{Information from levels 1 and 2, plus the current normed radius of the trust region.}
 #' \item{4}{Information from levels 1, 2, and 3, plus information from each estimate of the trust region subproblem (number of conjugate gradient iterations and how/why the CG algorithm terminated).}
 #' }
-#' 
+#'
 #' Default level is 2.  Levels 3 and 4 are available primarily for debugging purposes.
-#' 
+#'
 #' @section Stopping criteria:
 #' The algorithm will stop when one of the following three conditions are met:
 #' \itemize{
@@ -97,15 +97,34 @@
 #' \item{The algorithm proposes zero or negative improvement in the objective function (should never happen)}
 #' \item{The number of iterations reaches the control parameter \code{maxit}}
 #' }
-#' 
+#'
 #' If the algorithm appears to have stopped prematurely (i.e., the norm of the gradient is still too large), then one might just restart the algorithm.  For the quasi-Newton algorithms (\code{SR1} and \code{BFGS}), this will refresh the Hessian, and might allow more progress to be made.
 #'
 #' @section Estimating a sparse Hessian:
 #' Sometimes estimating the Hessian is easy (e.g., you have an analytic representation, or you are using some kind of algorithmic differentiation software).  If you do not know the Hessian, but you do know the sparsity structure, try the \pkg{sparseHessianFD} package. The routines in \pkg{sparseHessianFD} compute the Hessian using finite differencing, but in a way that exploits the sparsity structure.  In many cases, this can be faster than constructing an analytic Hessian for a large problem (e.g., when the Hessian has a block-arrow structure with a large number of blocks).
-#' 
+#'
 #' To use the \pkg{sparseHessianFD} package, you need to provide the row and column indices of the non-zero elements of the lower triangle of the Hessian. This structure cannot change during the course of the trust.optim routine.  Also, you really should provide an analytic gradient.  \pkg{sparseHessianFD} computes finite differences of the gradient, so if the gradient itself is finite-differenced, so much error is propagated through that the Hessians are nearly worthless close to the optimum.
-#' 
+#'
 #' Of course, \pkg{sparseHessianFD} is useful only for the \code{Sparse} method.  That said, one may still get decent performance using these routines even if the Hessian is sparse, if the problem is not too large.  Just treat the Hessian as if it were sparse.
+#' @examples
+#' \dontrun{
+#' data(binary)
+#' N <- length(binary$Y)
+#' k <- NROW(binary$X)
+#' start <- rep(0,(N+1)*k)
+#' priors <- list(inv.Sigma = diag(k), inv.Omega = diag(k))
+#' opt <- trust.optim(start, fn=binary.f,
+#'                   gr = binary.grad,  
+#'                   hs = binary.hess,
+#'                   method = "Sparse",
+#'                   control = list(
+#'                       report.precision=1L,
+#'                       function.scale.factor=-1
+#'                   ),
+#'                   data=binary, priors=priors
+#'                   )
+#' }
+#' 
 #' @export
 trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), control = list(), ...)
 {
@@ -113,15 +132,15 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
   if (is.null(method) || (match(method,c("SR1","BFGS","Sparse"),nomatch=0)==0)) {
     stop("Error in trust.optim:  method must be SR1, BFGS, or Sparse.")
   }
-  
+
   if (!is.function(fn)) stop ("Error in trust.optim:  fn must be a function")
   if (!is.function(gr)) stop ("Error in trust.optim:  gr must be a function")
-  
-  
+
+
   fn1 <- function(x) fn(x,...)  ## currying the data in
   gr1 <- if (!is.null(gr)) function(x) gr(x,...)
 
-    
+
 
 ## test fn and gr
 
@@ -136,7 +155,7 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
     r1 <- hs1(x)
     if (class(r1)!="dgCMatrix") stop("Error in trust.optim:  hs function must return object of class dgCMatrix")
   }
-  
+
     ## Defaults :
 
   con <- list(start.trust.radius=5.0,
@@ -152,7 +171,7 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
               contract.threshold = 0.25,
               expand.threshold.ap = 0.8,
               expand.threshold.radius = 0.8,
-              function.scale.factor = as.numeric(1),   
+              function.scale.factor = as.numeric(1),
               precond.refresh.freq=1L,
               preconditioner=0L,
               quasi.newton.method=0L,
@@ -169,8 +188,8 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
   con$report.precision <- as.integer(con$report.precision)
   con$precond.refresh.freq <- as.integer(con$precond.refresh.freq)
   con$maxit <- as.integer(con$maxit)
-  
-## check control parameter values here     
+
+## check control parameter values here
 
   if (!is.numeric(con$start.trust.radius) || con$start.trust.radius<=0 || !is.finite(con$start.trust.radius)) {
     stop("Error in trust.optim:  bad value for start.trust.radius.")
@@ -220,23 +239,22 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
     stop("Error in trust.optim:  expand.factor must be an non-negative numeric.")
   }
 
- 
+
 
   if (method=="Sparse") {
-     
-    con$quasi.newton.method <- 0L    
-##    res <- .Call("sparseTR", x, fn1, gr1, hs1, con)
+
+    con$quasi.newton.method <- 0L
     res <- sparseTR(x, fn1, gr1, hs1, con)
-    res$hessian <- Matrix::t(as(res$hessian,"symmetricMatrix"))
-    
+    res$hessian <- Matrix::t(methods::as(res$hessian,"symmetricMatrix"))
+
   }
 
   if (method=="SR1" || method=="BFGS") {
-    
+
     if (!is.null(hs)) {
       warning("warning: Hessian function will be ignored for quasi-Newton (non-sparse) method.")
     }
-    
+
     if (method=="SR1") {
       if (con$preconditioner==1) {
         warning("warning:  Cannot use Cholesky decomposition as preconditioner for SR1 method.  Using identity preconditioner instead.")
@@ -246,10 +264,9 @@ trust.optim <- function(x, fn, gr, hs=NULL, method=c("SR1","BFGS","Sparse"), con
     } else {
       con$quasi.newton.method <- 2L
     }
-    ##    res <- .Call("quasiTR", x, fn1, gr1, con)    
     res <- quasiTR(x, fn1, gr1, con)
 }
- 
+
   return(res)
 }
 
